@@ -1,13 +1,14 @@
-from dataclasses import dataclass, field
+import dataclasses
 from dataclasses_json import dataclass_json
+from sdk import utils
 
 
 @dataclass_json
-@dataclass
+@dataclasses.dataclass
 class EmbedAccessTokenResponse:
     r"""EmbedAccessTokenResponse
     An EmbedAccessTokenResponse contains a token that can be used to embed a Speakeasy dashboard.
     """
     
-    access_token: str = field(metadata={'dataclasses_json': { 'field_name': 'access_token' }})
+    access_token: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('access_token') }})
     
